@@ -14,17 +14,17 @@ from beneath.checkpointer import Checkpointer, PrefixedCheckpointer
 from beneath.config import DEFAULT_READ_BATCH_SIZE
 from beneath.connection import Connection, GraphQLError
 from beneath.consumer import Consumer
-from beneath.instance import StreamInstance
+from beneath.instance import TableInstance
 from beneath.job import Job
-from beneath.stream import Stream
-from beneath.utils import infer_avro, ProjectQualifier, StreamQualifier, SubscriptionQualifier
+from beneath.table import Table
+from beneath.utils import infer_avro, ProjectQualifier, TableQualifier, SubscriptionQualifier
 from beneath.writer import DryWriter, Writer
 
 
 class Client:
     """
     The main class for interacting with Beneath.
-    Data-related features (like defining streams and reading/writing data) are implemented
+    Data-related features (like defining tables and reading/writing data) are implemented
     directly on `Client`, while control-plane features (like creating projects) are isolated in
     the `admin` member.
 
@@ -38,7 +38,7 @@ class Client:
             reads as usual. It's useful for testing.
 
             The exact implication differs for different operations: Some mutations will be mocked,
-            such as creating a stream, others will fail with an exception. Write operations log
+            such as creating a table, others will fail with an exception. Write operations log
             records to the logger instead of transmitting to the server. Reads generally work, but
             throw an exception when called on mocked resources.
         write_delay_ms (int):
@@ -97,24 +97,24 @@ class Client:
         logger.setLevel(logging.INFO)
         return logger
 
-    # FINDING AND STAGING STREAMS
+    # FINDING AND STAGING TABLES
 
-    async def find_stream(self, stream_path: str) -> Stream:
+    async def find_table(self, table_path: str) -> Table:
         """
-        Finds an existing stream and returns an object that you can use to
-        read and write from/to the stream.
+        Finds an existing table and returns an object that you can use to
+        read and write from/to the table.
 
         Args:
             path (str):
-                The path to the stream in the format of "USERNAME/PROJECT/STREAM"
+                The path to the table in the format of "USERNAME/PROJECT/TABLE"
         """
-        qualifier = StreamQualifier.from_path(stream_path)
-        stream = await Stream._make(client=self, qualifier=qualifier)
-        return stream
+        qualifier = TableQualifier.from_path(table_path)
+        table = await Table._make(client=self, qualifier=qualifier)
+        return table
 
-    async def create_stream(
+    async def create_table(
         self,
-        stream_path: str,
+        table_path: str,
         schema: str,
         description: str = None,
         meta: bool = None,
@@ -127,45 +127,45 @@ class Client:
         schema_kind: str = "GraphQL",
         indexes: str = None,
         update_if_exists: bool = None,
-    ) -> Stream:
+    ) -> Table:
         """
-        Creates (or optionally updates if ``update_if_exists=True``) a stream and returns it.
+        Creates (or optionally updates if ``update_if_exists=True``) a table and returns it.
 
         Args:
-            stream_path (str):
-                The (desired) path to the stream in the format of "USERNAME/PROJECT/STREAM".
-                The project must already exist. If the stream doesn't exist yet, it creates it.
+            table_path (str):
+                The (desired) path to the table in the format of "USERNAME/PROJECT/TABLE".
+                The project must already exist. If the table doesn't exist yet, it creates it.
             schema (str):
-                The GraphQL schema for the stream. To learn about the schema definition language,
+                The GraphQL schema for the table. To learn about the schema definition language,
                 see https://about.beneath.dev/docs/reading-writing-data/schema-definition/.
             description (str):
-                The description shown for the stream in the web console. If not set, tries to infer
+                The description shown for the table in the web console. If not set, tries to infer
                 a description from the schema.
             retention (timedelta):
-                The amount of time to retain records written to the stream.
+                The amount of time to retain records written to the table.
                 If not set, records will be stored forever.
             schema_kind (str):
                 The parser to use for ``schema``. Currently must be "GraphQL" (default).
             update_if_exists (bool):
-                If true and the stream already exists, the provided info will be used to update
-                the stream (only supports non-breaking schema changes) before returning it.
+                If true and the table already exists, the provided info will be used to update
+                the table (only supports non-breaking schema changes) before returning it.
         """
-        qualifier = StreamQualifier.from_path(stream_path)
+        qualifier = TableQualifier.from_path(table_path)
         if self.dry:
-            data = await self.admin.streams.compile_schema(
+            data = await self.admin.tables.compile_schema(
                 schema_kind=schema_kind,
                 schema=schema,
             )
-            stream = await Stream._make_dry(
+            table = await Table._make_dry(
                 client=self,
                 qualifier=qualifier,
                 avro_schema=data["canonicalAvroSchema"],
             )
         else:
-            data = await self.admin.streams.create(
+            data = await self.admin.tables.create(
                 organization_name=qualifier.organization,
                 project_name=qualifier.project,
-                stream_name=qualifier.stream,
+                table_name=qualifier.table,
                 schema_kind=schema_kind,
                 schema=schema,
                 indexes=indexes,
@@ -184,8 +184,8 @@ class Client:
                 ),
                 update_if_exists=update_if_exists,
             )
-            stream = await Stream._make(client=self, qualifier=qualifier, admin_data=data)
-        return stream
+            table = await Table._make(client=self, qualifier=qualifier, admin_data=data)
+        return table
 
     @staticmethod
     def _timedelta_to_seconds(td: timedelta):
@@ -213,7 +213,7 @@ class Client:
                 The analytical SQL query to run. To learn about the query language,
                 see https://about.beneath.dev/docs/reading-writing-data/warehouse-queries/.
             analyze (bool):
-                If true, analyzes the query and returns info about referenced streams
+                If true, analyzes the query and returns info about referenced tables
                 and expected bytes scanned, but doesn't actually run the query.
             max_bytes_scanned (int):
                 Sets a limit on the number of bytes the query can scan.
@@ -262,7 +262,7 @@ class Client:
 
         self._start_count -= 1
 
-    async def write(self, instance: StreamInstance, records: Union[Mapping, Iterable[Mapping]]):
+    async def write(self, instance: TableInstance, records: Union[Mapping, Iterable[Mapping]]):
         """
         Writes one or more records to ``instance``. By default, writes are buffered for up to
         ``write_delay_ms`` milliseconds before being transmitted to the server. See the Client
@@ -272,7 +272,7 @@ class Client:
         terminating).
 
         Args:
-            instance (StreamInstance):
+            instance (TableInstance):
                 The instance to write to. You can also call ``instance.write`` as a convenience
                 wrapper.
             records:
@@ -284,40 +284,40 @@ class Client:
         await self._writer.write(instance, records)
 
     async def force_flush(self):
-        """ Forces the client to flush buffered writes without stopping """
+        """Forces the client to flush buffered writes without stopping"""
         await self._writer.force_flush()
 
     async def write_full(
         self,
-        stream_path: str,
+        table_path: str,
         records: Union[Iterable[dict], pd.DataFrame],
         key: Union[str, List[str]] = None,
         description: str = None,
         recreate_on_schema_change=False,
     ):
         """
-        Infers a schema, creates a stream, and writes a full dataset to Beneath.
-        Each call will create a new primary version for the stream, and delete the old primary
+        Infers a schema, creates a table, and writes a full dataset to Beneath.
+        Each call will create a new primary version for the table, and delete the old primary
         version if/when the write completes succesfully.
 
         Args:
-            stream_path (str):
-                The (desired) path to the stream in the format of "USERNAME/PROJECT/STREAM".
+            table_path (str):
+                The (desired) path to the table in the format of "USERNAME/PROJECT/TABLE".
                 The project must already exist.
             records (list(dict) | pandas.DataFrame):
                 The full dataset to write, either as a list of records or as a Pandas DataFrame.
-                This function uses ``beneath.infer_avro`` to infer a schema for the stream based
+                This function uses ``beneath.infer_avro`` to infer a schema for the table based
                 on the records.
             key (str | list(str)):
-                The fields to use as the stream's key. If not set, will default to the dataframe
+                The fields to use as the table's key. If not set, will default to the dataframe
                 index if ``records`` is a Pandas DataFrame, or add a column of incrementing numbers
                 if ``records`` is a list.
             description (str):
-                A description for the stream.
+                A description for the table.
             recreate_on_schema_change (bool):
-                If true, and there's an existing stream at ``stream_path`` with a schema that is
+                If true, and there's an existing table at ``table_path`` with a schema that is
                 incompatible with the inferred schema for ``records``, it will delete the existing
-                stream and create a new one instead of throwing an error. Defaults to false.
+                table and create a new one instead of throwing an error. Defaults to false.
         """
         if self._start_count == 0:
             raise Exception("Cannot call write_full because the client is stopped")
@@ -357,10 +357,10 @@ class Client:
         schema = infer_avro(records)
         indexes = json.dumps([{"key": True, "fields": key}])
 
-        # create the stream
+        # create the table
         try:
-            stream = await self.create_stream(
-                stream_path=stream_path,
+            table = await self.create_table(
+                table_path=table_path,
                 schema=schema,
                 description=description,
                 schema_kind="Avro",
@@ -372,15 +372,15 @@ class Client:
                 raise
             if not recreate_on_schema_change:
                 raise ValueError(
-                    "Cannot create stream because an existing stream *with a different schema* "
-                    f"already exists at '{stream_path}'. To delete the existing stream and all its"
+                    "Cannot create table because an existing table *with a different schema* "
+                    f"already exists at '{table_path}'. To delete the existing table and all its"
                     " versions and records, pass recreate_on_schema_change=True."
                 )
             # recreate
-            stream = await self.find_stream(stream_path)
-            await self.admin.streams.delete(stream_id=str(stream.stream_id))
-            stream = await self.create_stream(
-                stream_path=stream_path,
+            table = await self.find_table(table_path)
+            await self.admin.tables.delete(table_id=str(table.table_id))
+            table = await self.create_table(
+                table_path=table_path,
                 schema=schema,
                 description=description,
                 schema_kind="Avro",
@@ -391,13 +391,13 @@ class Client:
         # get instance
         next_instance = None
         previous_instance = None
-        if stream.primary_instance is None:
-            next_instance = await stream.create_instance()
-        elif stream.primary_instance.is_final:
-            next_instance = await stream.create_instance()
-            previous_instance = stream.primary_instance
+        if table.primary_instance is None:
+            next_instance = await table.create_instance()
+        elif table.primary_instance.is_final:
+            next_instance = await table.create_instance()
+            previous_instance = table.primary_instance
         else:
-            next_instance = stream.primary_instance
+            next_instance = table.primary_instance
 
         # write records
         if isinstance(records, pd.DataFrame):
@@ -409,7 +409,7 @@ class Client:
         if previous_instance:
             await previous_instance.delete()
 
-        return stream
+        return table
 
     # CHECKPOINTERS
 
@@ -417,14 +417,14 @@ class Client:
         self,
         project_path: str,
         key_prefix: str = None,
-        metastream_name="checkpoints",
-        metastream_create: bool = True,
-        metastream_description="Stores checkpointed state for consumers, pipelines, and more",
+        metatable_name="checkpoints",
+        metatable_create: bool = True,
+        metatable_description="Stores checkpointed state for consumers, pipelines, and more",
     ) -> Checkpointer:
         """
         Returns a checkpointer for the given project.
         Checkpointers store (small) key-value records useful for maintaining consumer and pipeline
-        state. State is stored in a meta-stream called "checkpoints" in the given project.
+        state. State is stored in a meta-table called "checkpoints" in the given project.
 
         Args:
             project_path (str):
@@ -432,29 +432,29 @@ class Client:
             key_prefix (str):
                 If set, any ``get`` or ``set`` call on the checkpointer will prepend the prefix
                 to the key.
-            metastream_name (str):
-                Name of the meta stream in which to save checkpointed data
-            metastream_create (bool):
-                If true, the checkpointer will create the checkpoints meta-stream if it does not
+            metatable_name (str):
+                Name of the meta table in which to save checkpointed data
+            metatable_create (bool):
+                If true, the checkpointer will create the checkpoints meta-table if it does not
                 already exists. If false, the checkpointer will throw an exception if the
-                meta-stream does not already exist. Defaults to True.
-            metastream_description (str):
-                An optional description to apply to the checkpoints meta-stream. Defaults to a
+                meta-table does not already exist. Defaults to True.
+            metatable_description (str):
+                An optional description to apply to the checkpoints meta-table. Defaults to a
                 sensible description of checkpointing.
         """
         project_qualifier = ProjectQualifier.from_path(project_path)
-        qualifier = StreamQualifier(
+        qualifier = TableQualifier(
             organization=project_qualifier.organization,
             project=project_qualifier.project,
-            stream=metastream_name,
+            table=metatable_name,
         )
 
         if qualifier not in self._checkpointers:
             checkpointer = Checkpointer(
                 client=self,
-                metastream_qualifier=qualifier,
-                metastream_create=metastream_create,
-                metastream_description=metastream_description,
+                metatable_qualifier=qualifier,
+                metatable_create=metatable_create,
+                metatable_description=metatable_description,
             )
             self._checkpointers[qualifier] = checkpointer
             if self._start_count != 0:
@@ -469,23 +469,23 @@ class Client:
 
     async def consumer(
         self,
-        stream_path: str,
+        table_path: str,
         version: int = None,
         batch_size: int = DEFAULT_READ_BATCH_SIZE,
         subscription_path: str = None,
         checkpointer: Checkpointer = None,
-        metastream_create: bool = True,
+        metatable_create: bool = True,
     ):
         """
-        Creates a consumer for the given stream.
-        Consumers make it easy to replay the history of a stream and/or subscribe to new changes.
+        Creates a consumer for the given table.
+        Consumers make it easy to replay the history of a table and/or subscribe to new changes.
 
         Args:
-            stream_path (str):
-                Path to the stream to subscribe to. The consumer will subscribe to the stream's
+            table_path (str):
+                Path to the table to subscribe to. The consumer will subscribe to the table's
                 primary version.
             version (int):
-                The instance version to use for stream. If not set, uses the primary instance.
+                The instance version to use for table. If not set, uses the primary instance.
             batch_size (int):
                 Sets the max number of records to load in each network request. Defaults to 1000.
             subscription_path (str):
@@ -496,15 +496,15 @@ class Client:
             checkpointer (Checkpointer):
                 Only applies if ``subscription_path`` is set. Provides a specific checkpointer to
                 use for consumer state. If not set, will create one in the subscription's project.
-            metastream_create (bool):
+            metatable_create (bool):
                 Only applies if ``subscription_path`` is set and ``checkpointer`` is not set.
                 Passed through to ``client.checkpointer``.
         """
-        stream_qualifier = StreamQualifier.from_path(stream_path)
+        table_qualifier = TableQualifier.from_path(table_path)
         if not subscription_path:
             consumer = Consumer(
                 client=self,
-                stream_qualifier=stream_qualifier,
+                table_qualifier=table_qualifier,
                 batch_size=batch_size,
             )
             await consumer._init()
@@ -515,11 +515,11 @@ class Client:
             if checkpointer is None:
                 checkpointer = await self.checkpointer(
                     f"{sub_qualifier.organization}/{sub_qualifier.project}",
-                    metastream_create=metastream_create,
+                    metatable_create=metatable_create,
                 )
             consumer = Consumer(
                 client=self,
-                stream_qualifier=stream_qualifier,
+                table_qualifier=table_qualifier,
                 version=version,
                 batch_size=batch_size,
                 checkpointer=checkpointer,
