@@ -18,10 +18,10 @@ MAX_BATCH_SIZE_BYTES = 10000000
 MAX_BATCH_SIZE_COUNT = 10000
 
 if DEV:
-    BENEATH_FRONTEND_HOST = "http://localhost:3000"
-    BENEATH_CONTROL_HOST = "http://localhost:4000"
-    BENEATH_GATEWAY_HOST = "http://localhost:5000"
-    BENEATH_GATEWAY_HOST_GRPC = "localhost:50051"
+    BENEATH_FRONTEND_HOST = "http://host.docker.internal:3000"
+    BENEATH_CONTROL_HOST = "http://host.docker.internal:4000"
+    BENEATH_GATEWAY_HOST = "http://host.docker.internal:5000"
+    BENEATH_GATEWAY_HOST_GRPC = "host.docker.internal:50051"
 else:
     BENEATH_FRONTEND_HOST = "https://beneath.dev"
     BENEATH_CONTROL_HOST = "https://control.beneath.dev"
