@@ -1,11 +1,11 @@
-# Allows us to use Stream as a type hint without an import cycle
+# Allows us to use Table as a type hint without an import cycle
 # pylint: disable=wrong-import-position,ungrouped-imports
 from __future__ import annotations
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from beneath.client import Client
-    from beneath.stream import Stream
+    from beneath.table import Table
 
 from collections.abc import Mapping
 from typing import Iterable, Union
@@ -15,26 +15,26 @@ from beneath import config
 from beneath.cursor import Cursor
 
 
-class StreamInstance:
+class TableInstance:
     """
-    Represents an instance of a Stream, i.e. a specific version that you can query/subscribe/write
-    to. Learn more about instances at https://about.beneath.dev/docs/concepts/streams/.
+    Represents an instance of a Table, i.e. a specific version that you can query/subscribe/write
+    to. Learn more about instances at https://about.beneath.dev/docs/concepts/tables/.
     """
 
     # INITIALIZATION
 
     def __init__(self):
-        self.stream: Stream = None
-        """ The stream that this is an instance of """
+        self.table: Table = None
+        """ The table that this is an instance of """
 
         self.instance_id: uuid.UUID = None
-        """ The stream instance ID """
+        """ The table instance ID """
 
         self.is_final: bool = None
         """ True if the instance has been made final and is closed for further writes """
 
         self.is_primary: bool = None
-        """ True if the instance is the primary instance for the stream """
+        """ True if the instance is the primary instance for the table """
 
         self.version: int = None
         """ The instance's version number """
@@ -42,10 +42,10 @@ class StreamInstance:
         self._client: Client = None
 
     @classmethod
-    def _make(cls, client: Client, stream: Stream, admin_data: dict) -> StreamInstance:
-        instance = StreamInstance()
+    def _make(cls, client: Client, table: Table, admin_data: dict) -> TableInstance:
+        instance = TableInstance()
         instance._client = client
-        instance.stream = stream
+        instance.table = table
         instance._set_admin_data(admin_data)
         return instance
 
@@ -53,20 +53,20 @@ class StreamInstance:
     def _make_dry(
         cls,
         client: Client,
-        stream: Stream,
+        table: Table,
         version: int,
         make_primary=False,
-    ) -> StreamInstance:
-        instance = StreamInstance()
+    ) -> TableInstance:
+        instance = TableInstance()
         instance._client = client
-        instance.stream = stream
+        instance.table = table
         instance.instance_id = None
         instance.version = version
         instance.is_primary = make_primary
         return instance
 
     def _set_admin_data(self, admin_data: dict):
-        self.instance_id = uuid.UUID(hex=admin_data["streamInstanceID"])
+        self.instance_id = uuid.UUID(hex=admin_data["tableInstanceID"])
         self.version = admin_data["version"]
         self.is_final = admin_data["madeFinalOn"] is not None
         self.is_primary = admin_data["madePrimaryOn"] is not None
@@ -74,8 +74,8 @@ class StreamInstance:
     # STATE
 
     def __repr__(self):
-        url = f"{config.BENEATH_FRONTEND_HOST}/{self.stream._qualifier}/{self.version}"
-        return f'<beneath.stream.StreamInstance("{url}")>'
+        url = f"{config.BENEATH_FRONTEND_HOST}/{self.table._qualifier}/{self.version}"
+        return f'<beneath.table.TableInstance("{url}")>'
 
     # CONTROL PLANE
 
@@ -85,7 +85,7 @@ class StreamInstance:
         if self.instance_id:
             if make_final:
                 await self._client.force_flush()
-            admin_data = await self._client.admin.streams.update_instance(
+            admin_data = await self._client.admin.tables.update_instance(
                 instance_id=str(self.instance_id),
                 make_primary=make_primary,
                 make_final=make_final,
@@ -95,21 +95,21 @@ class StreamInstance:
             self.is_final = self.is_final or make_final
             self.is_primary = self.is_primary or make_primary
         if make_primary:
-            self.stream.primary_instance = self
+            self.table.primary_instance = self
 
     async def delete(self):
         """ Deletes the instance """
         if self.instance_id:
-            await self._client.admin.streams.delete_instance(instance_id=str(self.instance_id))
-        if self.stream.primary_instance == self:
-            self.stream.primary_instance = None
+            await self._client.admin.tables.delete_instance(instance_id=str(self.instance_id))
+        if self.table.primary_instance == self:
+            self.table.primary_instance = None
 
     # READING RECORDS
 
     async def query_log(self, peek: bool = False) -> Cursor:
         """
-        Queries the stream's log, returning a cursor for replaying every record
-        written to the instance or for subscribing to new changes records in the stream.
+        Queries the table's log, returning a cursor for replaying every record
+        written to the instance or for subscribing to new changes records in the table.
 
         Args:
             peek (bool):
@@ -125,7 +125,7 @@ class StreamInstance:
         changes = resp.change_cursors[0] if len(resp.change_cursors) > 0 else None
         return Cursor(
             connection=self._client.connection,
-            schema=self.stream.schema,
+            schema=self.table.schema,
             replay_cursor=replay,
             changes_cursor=changes,
         )
@@ -133,8 +133,8 @@ class StreamInstance:
     # pylint: disable=redefined-builtin
     async def query_index(self, filter: str = None) -> Cursor:
         """
-        Queries a sorted index of the records written to the stream. The index contains
-        the newest record for each record key (see the stream's schema for the key). Returns
+        Queries a sorted index of the records written to the table. The index contains
+        the newest record for each record key (see the table's schema for the key). Returns
         a cursor for paging through the index.
 
         Args:
@@ -155,7 +155,7 @@ class StreamInstance:
         changes = resp.change_cursors[0] if len(resp.change_cursors) > 0 else None
         return Cursor(
             connection=self._client.connection,
-            schema=self.stream.schema,
+            schema=self.table.schema,
             replay_cursor=replay,
             changes_cursor=changes,
         )
